@@ -16,7 +16,7 @@ from base import *
 from results import *
 import solver
 import reader
-import testing
+#import testing
 from parallel import *
 
 pyutilib.component.core.PluginGlobals.pop_env()
