@@ -25,17 +25,24 @@ class IProblemConverter(Interface):
     def convert(self, from_type, to_type):
         """Convert an instance of one type into another"""
 
+    def apply(self, *args, **kwargs):
+        """Convert an instance of one type into another"""
 
-def convert_problem(args, target_problem_type, valid_problem_types):
+
+def convert_problem( args, target_problem_type, valid_problem_types,
+                     has_capability=lambda x: False ):
     """
     Convert a problem, defined by the 'args' tuple, into another problem.
     """
     #print "HERE",args,target_problem_type,valid_problem_types
     if len(valid_problem_types) == 0:
        raise ConverterError, "No valid problem types"
+
     if not (target_problem_type is None or \
              target_problem_type in valid_problem_types):
-       raise ConverterError, "Problem type "+str(target_problem_type)+" is not valid"
+        msg = "Problem type '%s' is not valid"
+        raise ConverterError, msg % str( target_problem_type )
+
     if len(args) == 0:
        raise ConverterError, "Empty argument list"
 
@@ -88,7 +95,10 @@ def convert_problem(args, target_problem_type, valid_problem_types):
             if converter.can_convert(s_ptype,ptype):
                 tmp = [s_ptype,ptype] + list(args)
                 tmp = tuple(tmp)
-                problem_files, symbol_map = converter.apply(*tmp)
+                tmpkw = {'capabilities':has_capability}
+                problem_files, symbol_map = converter.apply(*tmp, **tmpkw)
                 return problem_files, ptype, symbol_map
-    raise ConverterError, "No conversion possible.  Source problem type: %s.  Valid target types: %s" % (str(source_ptype[0]),map(str,valid_ptypes))
 
+    msg = 'No conversion possible.  Source problem type: %s.  Valid target '  \
+          'types: %s'
+    raise ConverterError, msg % (str(source_ptype[0]), map(str,valid_ptypes))
