@@ -8,8 +8,7 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-__all__ = ['ISolverRegistration', 'SolverRegistration',
-            'IOptSolver', 'OptSolver', 'SolverFactory']
+__all__ = ['IOptSolver', 'OptSolver', 'SolverFactory']
 
 import os
 import sys
@@ -23,56 +22,18 @@ from pyutilib.component.core import *
 from pyutilib.component.config import *
 import pyutilib.common
 import pyutilib.misc
-
 import time
 
 
-class ISolverRegistration(Interface):
-    """An interface for accessing"""
-
-    def create(self, name=None):
-        """Create a solver, optionally specifying the name"""
-
-    def type(self):
-        """The type of solver supported by this service"""
-
-
-class SolverRegistration(Plugin):
-
-    implements(ISolverRegistration)
-
-    def __init__(self, type, cls):
-        self.name = type
-        self._type = type
-        self._cls = cls
-
-    def type(self):
-        return self._type
-
-    def create(self, **kwds):
-        return self._cls(**kwds)
-
-
-def SolverFactory(solver_name=None, **kwds):
-    ep = ExtensionPoint(ISolverRegistration)
-    if solver_name is None:
-        names = map(lambda x:x.name, ep())
-        names.sort()
-        return names
-    service = ep.service(solver_name)
-    if service is None:
-        ##print "Unknown solver=" + solver_name + " - no plugin registered for this solver type"
-        return None
-    else:
-        return ep.service(solver_name).create(**kwds)
-
-
 class IOptSolver(Interface):
     """Interface class for creating optimization solvers"""
 
     def available(self, exception_flag=True):
         """Determine if this optimizer is available."""
 
+    def warm_start_capable(self):
+       """ True is the solver can accept a warm-start solution."""        
+
     def solve(self, *args, **kwds):
         """Perform optimization and return an SolverResults object."""
 
@@ -83,6 +44,9 @@ class IOptSolver(Interface):
         """Set the options in the optimizer from a string."""
 
 
+SolverFactory = CreatePluginFactory(IOptSolver)
+
+
 class OptSolver(ManagedPlugin):
     """A generic optimization solver"""
 
@@ -116,7 +80,7 @@ class OptSolver(ManagedPlugin):
             else:
                 self._doc = "%s OptSolver (type %s)" % (self.name,self.type)
         declare_option("options", cls=DictOption, section=self.name, doc=self._doc)
-        if 'options' in kwds:
+        if 'options' in kwds and not kwds['options'] is None:
             for key in kwds['options']:
                 setattr(self.options,key,kwds['options'][key])
         self._symbol_map=None
@@ -139,6 +103,31 @@ class OptSolver(ManagedPlugin):
         # want to persistence of this parameter to be violated.
         self.mipgap = None
 
+        # We define no capabilities for the generic solver; base classes must override this
+        self._capabilities = pyutilib.misc.Options()
+
+    def has_capability(self, cap):
+        """
+        Returns a boolean value representing whether a solver supports
+        a specific feature. Defaults to 'False' if the solver is unaware
+        of an option. Expects a string.
+
+        Example:
+        print solver.sos1 # prints True if solver supports sos1 constraints,
+                          # and False otherwise
+        print solver.feature # prints True is solver supports 'feature', and
+                             # False otherwise
+        """
+        if not isinstance(cap, str):
+            raise TypeError, "Expected argument to be of type '%s', not " + \
+                  "'%s'." % (str(type(str())), str(type(cap)))
+        else:
+            val = self._capabilities[str(cap)]
+            if val is None:
+                return False
+            else:
+                return True
+
     def available(self, exception_flag=True):
         """ True if the solver is available """
         if self._assert_available:
@@ -191,7 +180,7 @@ class OptSolver(ManagedPlugin):
              self._assert_available=True
           elif key == "suffixes":
              val = kwds[key]
-             self._suffixes=kwds[key]
+             self.suffixes=kwds[key]
           else:
              raise ValueError, "Unknown option="+key+" for solver="+self.type
 
@@ -228,7 +217,7 @@ class OptSolver(ManagedPlugin):
         #
         # Otherwise, we try to convert the object explicitly.
         #
-        return convert_problem(args, pformat, valid_pformats)
+        return convert_problem(args, pformat, valid_pformats, self.has_capability)
 
     def _default_results_format(self, prob_format):
         """Returns the default results format for different problem
