@@ -316,6 +316,7 @@ class OSrL(object):
 from coopr.opt.base import results
 from coopr.opt.base.formats import *
 from coopr.opt import SolverResults
+from pyutilib.component.core import alias
 
 class ResultsReader_osrl(results.AbstractResultsReader):
     """
@@ -323,6 +324,8 @@ class ResultsReader_osrl(results.AbstractResultsReader):
     SolverResults object.
     """
 
+    alias(str(ResultsFormat.osrl))
+
     def __init__(self, name=None):
         results.AbstractResultsReader.__init__(self,ResultsFormat.osrl)
         if not name is None:
@@ -371,6 +374,3 @@ class ResultsReader_osrl(results.AbstractResultsReader):
           res.problem.number_of_objectives = len(soln.objective) 
         return res
 
-
-results.ReaderRegistration(str(ResultsFormat.osrl), ResultsReader_osrl)
-
