@@ -11,12 +11,11 @@ cooprdir = dirname(abspath(__file__))+os.sep+".."+os.sep+".."+os.sep
 currdir = dirname(abspath(__file__))+os.sep
 
 import re
-import unittest
 from nose.tools import nottest
 import coopr.opt
 from coopr.opt import ProblemFormat, ConverterError
 import coopr
-import pyutilib.th
+import pyutilib.th as unittest
 import pyutilib.services
 import pyutilib.component.config
 import pyutilib.component.core
@@ -68,7 +67,7 @@ class MockArg4(MockArg):
         INPUT.close()
 
 
-class OptConvertDebug(pyutilib.th.TestCase):
+class OptConvertDebug(unittest.TestCase):
 
     def setUp(self):
         pyutilib.services.TempfileManager.tempdir = currdir
