@@ -15,13 +15,16 @@ from nose.tools import nottest
 import coopr.opt
 import coopr
 import pyutilib.services
+from pyutilib.component.core import alias
 
 
-class TestSolver(coopr.opt.OptSolver):
+class TestSolver1(coopr.opt.OptSolver):
+
+    alias('stest1')
 
     def __init__(self, **kwds):
         kwds['type'] = 'stest_type'
-        kwds['doc'] = 'TestSolver Documentation'
+        kwds['doc'] = 'TestSolver1 Documentation'
         coopr.opt.OptSolver.__init__(self,**kwds)
 
     def enabled(self):
@@ -30,12 +33,8 @@ class TestSolver(coopr.opt.OptSolver):
     
 class OptSolverDebug(unittest.TestCase):
 
-    def run(self, result=None):
-        self.stest_plugin = coopr.opt.SolverRegistration("stest", TestSolver)
-        unittest.TestCase.run(self,result)
-        self.stest_plugin.deactivate()
-
     def setUp(self):
+        coopr.opt.SolverFactory.activate('stest1')
         pyutilib.services.TempfileManager.tempdir = currdir
 
     def tearDown(self):
@@ -46,17 +45,17 @@ class OptSolverDebug(unittest.TestCase):
         """
         Verify the processing of 'type', 'name' and 'doc' options
         """
-        ans = coopr.opt.SolverFactory("stest")
-        self.failUnlessEqual(type(ans), TestSolver)
-        self.failUnlessEqual(ans._doc, "TestSolver Documentation")
+        ans = coopr.opt.SolverFactory("stest1")
+        self.failUnlessEqual(type(ans), TestSolver1)
+        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
 
-        ans = coopr.opt.SolverFactory("stest", doc="My Doc")
-        self.failUnlessEqual(type(ans), TestSolver)
-        self.failUnlessEqual(ans._doc, "TestSolver Documentation")
+        ans = coopr.opt.SolverFactory("stest1", doc="My Doc")
+        self.failUnlessEqual(type(ans), TestSolver1)
+        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
 
-        ans = coopr.opt.SolverFactory("stest", name="my name")
-        self.failUnlessEqual(type(ans), TestSolver)
-        self.failUnlessEqual(ans._doc, "TestSolver Documentation")
+        ans = coopr.opt.SolverFactory("stest1", name="my name")
+        self.failUnlessEqual(type(ans), TestSolver1)
+        self.failUnlessEqual(ans._doc, "TestSolver1 Documentation")
 
     def test_solver_init2(self):
         """
@@ -65,15 +64,15 @@ class OptSolverDebug(unittest.TestCase):
         opt = {}
         opt['a'] = 1
         opt['b'] = "two"
-        ans = coopr.opt.SolverFactory("stest", name="solver_init2", options=opt)
+        ans = coopr.opt.SolverFactory("stest1", name="solver_init2", options=opt)
         self.failUnlessEqual(ans.options['a'], opt['a'])
         self.failUnlessEqual(ans.options['b'], opt['b'])
 
     def test_avail(self):
-        ans = coopr.opt.SolverFactory("stest")
+        ans = coopr.opt.SolverFactory("stest1")
         try:
             ans.available()
-            self.fail("Expected exception for 'stest' solver, which is disabled")
+            self.fail("Expected exception for 'stest1' solver, which is disabled")
         except pyutilib.common.ApplicationError:
             pass
 
